A colour metric based on the ISCC-NBS System of Colour Designation.
Usage
ISCCNBSblock(colour, colourList, …)
Arguments
colour
An "sRGB" colour object representing colours to find a match for.
colourList
An "sRGB" colour object representing a list of colours to
find a match within.
…
Other arguments passed by the colourMatch function from the
roloc package.
Value
A matrix of distances, with one row per colour specification and one
column per colour name.
Details
All colours and all if colourList are converted to
an ISCCNBS block. The distance between a colour specification and
a colour name is 0 if both are within the same block or Inf
if they are not in the same block. It is also possible that either
the colour specification or the colour name does not correspond to
any block (could not be converted), in which case the distance is
NA.