ISCCNBScolours: An ISCC-NBS Colour List

Description Usage Format Author(s) Examples

Description

A colour list based on the ISCC-NBS System of Colour Designation. There are 267 colour names, with each name corresponding to a "block" or region of Munsell colour space. The sRGB colour for each name in the list represents the centroid of the relevant block.

Usage

1

Format

A "colourList" object.

Author(s)

Paul Murrell

Examples

1
2
3
colourName(palette())
colourName(palette(), colourList=ISCCNBScolours)
colourName(palette(), colourList=ISCCNBScolours, colourMetric=ISCCNBSblock)

pmur002/rolocISCCNBS documentation built on May 23, 2019, 1:27 p.m.