Learn R Programming

rolocISCCNBS (version 0.1)

ISCCNBScolours: An ISCC-NBS Colour List

Description

A colour list based on the ISCC-NBS System of Colour Designation. There are 267 colour names, with each name corresponding to a "block" or region of Munsell colour space. The sRGB colour for each name in the list represents the centroid of the relevant block.

Usage

ISCCNBScolours

Arguments

Format

A "colourList" object.

Examples

Run this code
# NOT RUN {
colourName(palette())
colourName(palette(), colourList=ISCCNBScolours)
colourName(palette(), colourList=ISCCNBScolours, colourMetric=ISCCNBSblock)
# }

Run the code above in your browser using DataLab